==> gofannon-0.25.15.1.tar.gz: gofannon-0.25.15.1/README.md <==
![logo](https://the-ai-alliance.github.io/gofannon/assets/images/logo_1000x1260.png)
<!-- ![CI](https://github.com/The-AI-Alliance/gofannon/actions/workflows/main.yml/badge.svg) -->
![PyPI](https://img.shields.io/pypi/v/gofannon)
![License](https://img.shields.io/github/license/The-AI-Alliance/gofannon)
![Issues](https://img.shields.io/github/issues/The-AI-Alliance/gofannon)
![GitHub stars](https://img.shields.io/github/stars/The-AI-Alliance/gofannon?style=social)

# `gofannon`  
  
**[gofannon](https://the-ai-alliance.github.io/gofannon/)** is a collection of tools designed to enhance the capabilities of 
function-calling-enabled language models/agents. These tools provide additional
functionality for various tasks.  


## 🌟🌟 Features 🌟🌟 

1. Cross-Framework Compatibility (Import From/Export To Multiple Frameworks)
   - **Current:** `smolagents`, LangChain, AWS Bedrock
   - **Currently Being Developed:** [Up To Date List](https://github.com/The-AI-Alliance/gofannon/issues?q=is%3Aissue%20state%3Aopen%20label%3Aframework%20assignee:*)
   - **In The Roadmap:** [Up To Date List](https://github.com/The-AI-Alliance/gofannon/issues?q=is%3Aissue%20state%3Aopen%20label%3Aframework%20no%3Aassignee)
2. A Robust Collection of Tools
   - List [Here](https://github.com/The-AI-Alliance/gofannon/pulls?q=is%3Apr+is%3Aclosed+label%3Atool)
   - New Tools being added daily
3. New Contributor Friendly
   - [Curated contribution pathways](https://the-ai-alliance.github.io/gofannon/developers/) 
   - [Gamified Contributor Process](https://the-ai-alliance.github.io/gofannon/leaderboard.html)
## 🎓🎓 Why the name `gofannon`? 🎓🎓

See [`why_the_name_gofannon`](https://the-ai-alliance.github.io/gofannon/about/the_name_gofannon/) for the rich story on why we chose to honor this Celtic Diety

## ⚡️⚡️Quickstart ⚡️⚡️

```bash  
pip install gofannon  
```

gofannon is an ambitious upstart, things are happening fast. We have a git
action that deploys to PyPi every Monday morning, so `pip install gofannon`
will get you pretty close to the tip of the spear. But if you absolutely _must_
have the latest and greatest, this will work too:

```bash
git+https://github.com/The-AI-Alliance/gofannon.git@main
```

For more information, see out [quickstart guide](https://github.com/The-AI-Alliance/gofannon/blob/main/docs/quickstart.md).

## 🏆🏆 Acknowledgments 🏆🏆

We would like to thank the open-source community for their contributions and support in making this project possible.

<a href="https://github.com/The-AI-Alliance/gofannon/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=The-AI-Alliance/gofannon" />
</a>

Made with [contrib.rocks](https://contrib.rocks).

## 🗞️🗞️ Stay Up To Date 🗞️🗞️

Star `gofannon` for good karma (and to receive updates in your github feed).

![gif showng how to star](https://the-ai-alliance.github.io/gofannon/assets/images/github-star.gif)

## 🚲🚲 Roadmap  🚲🚲
  
For a detailed overview of planned features and their current status, please refer to the [ROADMAP](https://github.com/The-AI-Alliance/gofannon/blob/main/ROADMAP.md).   

## 📘📘 Documentation 📘📘

Documentation can be found [here](https://github.com/The-AI-Alliance/gofannon/tree/main/docs). Each tool comes with its own documentation, which can be found in the docs/ directory. The documentation provides detailed information on how to use each tool, including required parameters and example usage.

## ☎️☎️ Contact Us ☎️☎️

[Contact Information](https://the-ai-alliance.github.io/gofannon/community/contact.html)

## 🧑‍⚖️🧑‍⚖️ License 🧑‍⚖️🧑‍⚖️
  
This project is licensed under the ASFv2 License. See the [LICENSE](https://github.com/The-AI-Alliance/gofannon/blob/main/LICENSE) file for more details.

==> gofannon-0.25.47.tar.gz: gofannon-0.25.47/README.md <==
![logo](https://the-ai-alliance.github.io/gofannon/assets/images/logo_1000x1260.png)
<!-- ![CI](https://github.com/The-AI-Alliance/gofannon/actions/workflows/main.yml/badge.svg) -->
![PyPI](https://img.shields.io/pypi/v/gofannon)
![License](https://img.shields.io/github/license/The-AI-Alliance/gofannon)
![Issues](https://img.shields.io/github/issues/The-AI-Alliance/gofannon)
![GitHub stars](https://img.shields.io/github/stars/The-AI-Alliance/gofannon?style=social)

# `gofannon`  
  
**[gofannon](https://the-ai-alliance.github.io/gofannon/)** is a collection of tools designed to enhance the capabilities of 
function-calling-enabled language models/agents. These tools provide additional
functionality for various tasks.  


## 🌟🌟 Features 🌟🌟 

1. Cross-Framework Compatibility (Import From/Export To Multiple Frameworks)
   - **Current:** `smolagents`, LangChain, AWS Bedrock, Google ADK
   - **Currently Being Developed:** [Up To Date List](https://github.com/The-AI-Alliance/gofannon/issues?q=is%3Aissue%20state%3Aopen%20label%3Aframework%20assignee:*)
   - **In The Roadmap:** [Up To Date List](https://github.com/The-AI-Alliance/gofannon/issues?q=is%3Aissue%20state%3Aopen%20label%3Aframework%20no%3Aassignee)
2. A Robust Collection of Tools
   - List [Here](https://github.com/The-AI-Alliance/gofannon/pulls?q=is%3Apr+is%3Aclosed+label%3Atool)
   - New Tools being added daily
3. New Contributor Friendly
   - [Curated contribution pathways](https://the-ai-alliance.github.io/gofannon/developers/) 
   - [Gamified Contributor Process](https://the-ai-alliance.github.io/gofannon/leaderboard.html)
## 🎓🎓 Why the name `gofannon`? 🎓🎓

See [`why_the_name_gofannon`](https://the-ai-alliance.github.io/gofannon/about/the_name_gofannon/) for the rich story on why we chose to honor this Celtic Diety

## ⚡️⚡️Quickstart ⚡️⚡️

```bash  
pip install gofannon  
```

gofannon is an ambitious upstart, things are happening fast. We have a git
action that deploys to PyPi every Monday morning, so `pip install gofannon`
will get you pretty close to the tip of the spear. But if you absolutely _must_
have the latest and greatest, this will work too:

```bash
git+https://github.com/The-AI-Alliance/gofannon.git@main
```

For more information, see our [quickstart guide](https://github.com/The-AI-Alliance/gofannon/blob/main/docs/quickstart.md).

## 🏆🏆 Acknowledgments 🏆🏆

We would like to thank the open-source community for their contributions and support in making this project possible.

<a href="https://github.com/The-AI-Alliance/gofannon/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=The-AI-Alliance/gofannon" />
</a>

Made with [contrib.rocks](https://contrib.rocks).

## 🗞️🗞️ Stay Up To Date 🗞️🗞️

Star `gofannon` for good karma (and to receive updates in your github feed).

![gif showng how to star](https://the-ai-alliance.github.io/gofannon/assets/images/github-star.gif)

## 🚲🚲 Roadmap  🚲🚲
  
For a detailed overview of planned features and their current status, please refer to the [ROADMAP](https://github.com/The-AI-Alliance/gofannon/blob/main/ROADMAP.md).   

## 📘📘 Documentation 📘📘

Documentation can be found [here](https://github.com/The-AI-Alliance/gofannon/tree/main/docs). Each tool comes with its own documentation, which can be found in the docs/ directory. The documentation provides detailed information on how to use each tool, including required parameters and example usage.

## ☎️☎️ Contact Us ☎️☎️

[Contact Information](https://the-ai-alliance.github.io/gofannon/community/contact.html)

## 🧑‍⚖️🧑‍⚖️ License 🧑‍⚖️🧑‍⚖️
  
This project is licensed under the ASFv2 License. See the [LICENSE](https://github.com/The-AI-Alliance/gofannon/blob/main/LICENSE) file for more details.
